@@ -6,12 +6,12 @@ use std::str::FromStr;
 
 const DEFAULT_LOG_LEVEL: log::LevelFilter = log::LevelFilter::Info;
 
-pub fn init() {
-    simple_logging::log_to_stderr(get_log_level());
+pub fn init(env_var_name: &str) {
+    simple_logging::log_to_stderr(get_log_level(env_var_name));
 }
 
-fn get_log_level() -> log::LevelFilter {
-    let log_level_string = match env::var("FPM_LOG_LEVEL") {
+fn get_log_level(env_var_name: &str) -> log::LevelFilter {
+    let log_level_string = match env::var(env_var_name) {
         Ok(level) => level,
         Err(_) => return DEFAULT_LOG_LEVEL,
     };
